import figures.*;

import java.util.*;
import stiftUndCo.*;
import java.awt.*;

public class PongBall extends Kreis
{

	private double dir, spd, brad, xk, yk;
	private Bildschirm scr;

public PongBall(double x, double y, double rad, double richtung, double geschwindigkeit, Bildschirm bildschirm)
{
	super(x,y,rad);

	dir = richtung;
	spd = geschwindigkeit;
	scr = bildschirm;
	xk = x;
	yk = y;

}

public double getDir()
{
	return(dir);
}

public void SetzeRichtung(double richtung)
{
	dir = richtung;
}
public void SetzePos(double nx, double ny)
{
	verschiebe(nx-getX(),ny-getY());
}


public void SetzeGeschwindigkeit(double geschwindigkeit)
{
	spd = geschwindigkeit;
}

public boolean checkL()
{
	return(getX()-getRad() <= 0);
}

public boolean checkR()
{
	return(getX()+getRad() >= scr.breite());
}

public void bewege()
{
	verschiebe(Hilfe.cosinus(dir)*spd,-Hilfe.sinus(dir)*spd);

	// Abprallen

	if(getX()-getRad() <= 0 || getX()+getRad() >= scr.breite())
	{
		dir = 180-dir + Hilfe.zufall(-2,2);
	}

	if(getY()-getRad() <= 0 || getY()+getRad() >= scr.hoehe())
	{
		dir = -dir + Hilfe.zufall(-2,2);
	}



}

}
